pub fn mark_unexpected<T>(value: &T, format: &DiffFormat) -> StringExpand description
Highlights the given value as “unexpected value” using the color for
unexpected values or bold as specified by the given DiffFormat.
pub fn mark_unexpected<T>(value: &T, format: &DiffFormat) -> StringHighlights the given value as “unexpected value” using the color for
unexpected values or bold as specified by the given DiffFormat.