All

Struct All 

pub struct All<E>(pub E);
A combinator expectation that verifies that all containing expectations are met.

Use the function all() to construct an All combinator for a tuple of expectations.

Tuple Fields

0: E