Not

Struct Not 

pub struct Not<E>(pub E);
A combinator expectation that inverts the wrapped expectation.

This combinator can only be used with expectations that implement the Invertible trait (additional to the Expectation trait).

Most of the expectations provided by this crate do implement the Invertible trait and thus can be used with the Not combinator.

Use the function not() to construct a Not combinator containing the given expectation.

Tuple Fields

0: E