IntoRec

Trait IntoRec 

pub trait IntoRec {
    type Output;

    // Required method
    fn into_rec(self) -> Self::Output;
}
Trait to convert a type into another type that wraps the contained expectation(s) into Rec(s).

If this type contains multiple expectations like Vec<E: Expectation> or tuples of expectations, each expectation should be wrapped into its own Rec.

Required Associated Types

type Output

The result type with the expectation(s) wrapped into Rec.

Required Methods

fn into_rec(self) -> Self::Output

Wraps an expectation of this type into Rec.

If this type contains multiple expectations like Vec<E: Expectation or tuples of expectations, each expectation should be wrapped into its own Rec.

Implementations on Foreign Types

Source

impl<A1: Into<Rec<A1>>> IntoRec for (A1,)

Source

type Output = (Rec<A1>,)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>> IntoRec for (A1, A2)

Source

type Output = (Rec<A1>, Rec<A2>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>> IntoRec for (A1, A2, A3)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>> IntoRec for (A1, A2, A3, A4)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>> IntoRec for (A1, A2, A3, A4, A5)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>> IntoRec for (A1, A2, A3, A4, A5, A6)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>, A8: Into<Rec<A8>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7, A8)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>, A8: Into<Rec<A8>>, A9: Into<Rec<A9>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7, A8, A9)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>, A8: Into<Rec<A8>>, A9: Into<Rec<A9>>, A10: Into<Rec<A10>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7, A8, A9, A10)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>, A8: Into<Rec<A8>>, A9: Into<Rec<A9>>, A10: Into<Rec<A10>>, A11: Into<Rec<A11>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>)

Source

fn into_rec(self) -> Self::Output

Source

impl<A1: Into<Rec<A1>>, A2: Into<Rec<A2>>, A3: Into<Rec<A3>>, A4: Into<Rec<A4>>, A5: Into<Rec<A5>>, A6: Into<Rec<A6>>, A7: Into<Rec<A7>>, A8: Into<Rec<A8>>, A9: Into<Rec<A9>>, A10: Into<Rec<A10>>, A11: Into<Rec<A11>>, A12: Into<Rec<A12>>> IntoRec for (A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12)

Source

type Output = (Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>, Rec<A12>)

Source

fn into_rec(self) -> Self::Output

Implementors