Trait LengthProperty

pub trait LengthProperty {
    // Required method
    fn length_property(&self) -> usize;
}
Any type that implements this trait provides access to its len method to be used by the implementation of the AssertHasLength assertion.

Required Methods

fn length_property(&self) -> usize

Provides access to the len property.

Implementations on Foreign Types

Source

impl LengthProperty for &str

Source

impl LengthProperty for &OsStr

Source

impl LengthProperty for String

Source

impl LengthProperty for OsString

Source

impl<K, V> LengthProperty for BTreeMap<K, V>

Source

impl<K, V, S> LengthProperty for HashMap<K, V, S>

Source

impl<K, V, S> LengthProperty for HashMap<K, V, S>

Source

impl<T> LengthProperty for &[T]

Source

impl<T> LengthProperty for &T
where T: LengthProperty + ?Sized,

Source

impl<T> LengthProperty for &mut T
where T: LengthProperty + ?Sized,

Source

impl<T> LengthProperty for BinaryHeap<T>

Source

impl<T> LengthProperty for BTreeSet<T>

Source

impl<T> LengthProperty for LinkedList<T>

Source

impl<T> LengthProperty for VecDeque<T>

Source

impl<T> LengthProperty for Vec<T>

Source

impl<T, S> LengthProperty for HashSet<T, S>

Source

impl<T, S> LengthProperty for HashSet<T, S>

Source

impl<T, const N: usize> LengthProperty for [T; N]

Implementors