to_recursive_value

Function to_recursive_value 

pub fn to_recursive_value<T>(object: &T) -> Result<Value, Error>
where T: Serialize + ?Sized,
Available on crate feature recursive only.
Serializes the given object of some type into a Value. The given type must implement serde::Serialize.

Errors

This method returns a Result as of the API of serde. As the given object is serialized into an in-memory representation, there are practically no errors that can occur.