pub fn seq(values: impl IntoIterator<Item = Value>) -> ValueAvailable on crate feature
recursive only.Expand description
Constructs a Value representing the given sequence of Value values.
pub fn seq(values: impl IntoIterator<Item = Value>) -> Valuerecursive only.Constructs a Value representing the given sequence of Value values.