pub struct Spec<'a, S, R> { /* private fields */ }Expand description
Data of an actual assertion.
It holds the data needed to execute an assertion such as the subject, the name of the subject or expression, an optional description of the current assertion, and the location of the assertion in the source code respectively test code.
It also holds the concrete FailingStrategy on how to behave in case
an assertion fails.
In case of the CollectFailures failing strategy, the AssertFailures
are collected in this struct.
Implementations
Sourceimpl<S, R> Spec<'_, S, R>
impl<S, R> Spec<'_, S, R>
Sourcepub fn expression(&self) -> &Expression<'_>
pub fn expression(&self) -> &Expression<'_>
Returns the expression (or subject name) if one has been set.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Returns the description or the assertion if it has been set.
Sourcepub const fn diff_format(&self) -> &DiffFormat
pub const fn diff_format(&self) -> &DiffFormat
Returns the diff format used with this assertion.
Sourcepub fn failing_strategy(&self) -> &R
pub fn failing_strategy(&self) -> &R
Returns the failing strategy used in case an assertion fails.
Sourceimpl<'a, S, R> Spec<'a, S, R>
impl<'a, S, R> Spec<'a, S, R>
Sourcepub fn new(subject: S, failing_strategy: R) -> Self
pub fn new(subject: S, failing_strategy: R) -> Self
Constructs a new Spec for the given subject and with the specified
failing strategy.
The diff format is set to “no highlighting”. Failure messages will not highlight differences between the actual and the expected value.
Sourcepub fn named(self, subject_name: impl Into<Cow<'a, str>>) -> Self
pub fn named(self, subject_name: impl Into<Cow<'a, str>>) -> Self
Sets the subject name or expression for this assertion.
Sourcepub fn described_as(self, description: impl Into<Cow<'a, str>>) -> Self
pub fn described_as(self, description: impl Into<Cow<'a, str>>) -> Self
Sets a custom description about what is being asserted.
Sourcepub const fn located_at(self, location: Location<'a>) -> Self
pub const fn located_at(self, location: Location<'a>) -> Self
Sets the location of the assertion in the source code respectively test code.
Sourcepub const fn with_diff_format(self, diff_format: DiffFormat) -> Self
pub const fn with_diff_format(self, diff_format: DiffFormat) -> Self
Sets the diff format used to highlight differences between the actual value and the expected value.
Note: This method must be called before an assertion method is called to affect the failure message of the assertion as failure messages are formatted immediately when an assertion is executed.
Sourcepub fn with_configured_diff_format(self) -> Self
Available on crate feature colored only.
pub fn with_configured_diff_format(self) -> Self
colored only.Sets the diff format used to highlight differences between the actual value and the expected value according to the configured mode.
The mode is configured via environment variables as described in the module colored.
Sourcepub fn using_recursive_comparison(self) -> RecursiveComparison<'a, S, R>
Available on crate feature recursive only.
pub fn using_recursive_comparison(self) -> RecursiveComparison<'a, S, R>
recursive only.Switches this Spec to the “field-by-field recursive comparison
mode”.
It returns a RecursiveComparison which is a specialized Spec that
provides extra configuration options for the recursive comparison and
the special is_equivalent_to/is_not_equivalent_to assertions of the
AssertEquivalence trait.
See the documentation of the recursive_comparison module for details
about field-by-field recursive comparison.
Sourcepub fn extracting_ref<F, B, U>(
self,
property_name: impl Into<Cow<'a, str>>,
extract: F,
) -> DerivedSpec<'a, Self, U>
pub fn extracting_ref<F, B, U>( self, property_name: impl Into<Cow<'a, str>>, extract: F, ) -> DerivedSpec<'a, Self, U>
Extracts a property from the current subject.
The extracting closure gets a reference to the current subject as an argument and should return a reference to the extracted property. The given property name is used in failure reports for referencing the property for which an assertion fails.
Use this method if you want to extract multiple properties from the
same subject for individual assertions on each of these properties.
To extract another property from the original subject, call the and
method to switch back to the original subject before calling
extracting_ref for the other property.
The expression for failure reports is built from the expression of the
original subject, a dot as a separator, and the given property name.
The resulting expression is equal to
format!("{original_expression}.{property_name}").
If you do not like the default built expression, it can be overwritten
by calling the named method after the call to the extract method.
Arguments
property_name- A name describing the extracted property used for referencing this property in failure reports.extract- A closure that returns a reference to the property to be extracted.
Examples
use asserting::prelude::*;
#[derive(Debug, Clone, Copy, PartialEq)]
enum Gender {
Male,
Female,
NonBinary,
PreferNotToSay,
}
struct Person {
name: String,
age: u8,
gender: Gender,
}
impl Person {
fn name(&self) -> &str {
&self.name
}
}
let my_friend = Person {
name: "Silvia".into(),
age: 27,
gender: Gender::Female,
};
assert_that!(my_friend)
.extracting_ref("name", Person::name)
.is_equal_to("Silvia")
.and()
.extracting_ref("age", |p| &p.age)
.is_at_least(18)
.and()
.extracting_ref("gender", |p| &p.gender)
.is_equal_to(Gender::Female);Sourcepub fn extracting<F, U>(
self,
property_name: impl Into<Cow<'a, str>>,
extract: F,
) -> Spec<'a, U, R>where
F: FnOnce(S) -> U,
pub fn extracting<F, U>(
self,
property_name: impl Into<Cow<'a, str>>,
extract: F,
) -> Spec<'a, U, R>where
F: FnOnce(S) -> U,
Maps the current subject to some other value.
It takes a closure that maps the current subject to a new subject and
returns a new Spec with the value returned by the closure as the new
subject. The new subject may have a different type than the original
subject. All other data like description, location, and diff format are
taken over from this Spec into the returned Spec.
This method is useful when having a custom type, and one specific
property of this type shall be asserted only. If you want to assert
multiple properties of the same subject, use the extracting_ref
method instead.
This method is similar to the mapping method. In contrast to
mapping, this method does not copy the subject’s name
(or expression) but builds a new expression from the given
property_name and the expression of the original subject. The
idea is that the “extracted” property is most likely a different subject
than the original one.
The expression for failure reports is built from the expression of the
original subject, a dot as a separator, and the given property name.
The resulting expression is equal to
format!("{original_expression}.{property_name}").
If you do not like the default built expression, it can be overwritten
by calling the named method after the call to the extract method.
Arguments
property_name- A name describing the extracted property used for referencing this property in failure reports.extract- A closure that returns the property to be extracted.
Example
use asserting::prelude::*;
struct MyStruct {
important_property: String,
other_property: f64,
}
let some_thing = MyStruct {
important_property: "imperdiet aliqua zzril eiusmod".into(),
other_property: 99.9,
};
assert_that!(some_thing)
.extracting("important_property", |s| s.important_property)
.is_equal_to("imperdiet aliqua zzril eiusmod");In this example the resulting expression used in failure reports to
reference the asserted subject is "some_thing.important_property".
To overwrite the default built expression for failure reports, we can
call the named method, like so:
assert_that!(some_thing)
.extracting("important_property", |s| s.important_property)
.is_equal_to("imperdiet aliqua zzril eiusmod")
.named("my_struct's important property");Sourcepub fn mapping<F, U>(self, map: F) -> Spec<'a, U, R>where
F: FnOnce(S) -> U,
pub fn mapping<F, U>(self, map: F) -> Spec<'a, U, R>where
F: FnOnce(S) -> U,
Maps the current subject to some other value.
It takes a closure that maps the current subject to a new subject and
returns a new Spec with the value returned by the closure as the new
subject. The new subject may have a different type than the original
subject. All other data like expression, description, and location are
taken over from this Spec into the returned Spec.
This method is useful if some type does not implement a trait required for an assertion.
Spec also provides the extracting() method,
which is similar to this method. In contrast to this method,
extracting() does not copy the subject’s name
(or expression) but builds a new expression from the expression of the
original subject and the given property name.
Example
use asserting::prelude::*;
struct Point {
x: i64,
y: i64,
}
let target = Point { x: 12, y: -64 };
assert_that!(target).mapping(|s| (s.x, s.y)).is_equal_to((12, -64));The custom type Point does not implement the PartialEq trait nor
the Debug trait, which are both required for an is_equal_to
assertion. So we map the subject of the type Point to a tuple of its
fields.