pub struct Unknown;Expand description
Used with generic types in expectations where the concrete type is not relevant for the failure message.
This type implements the std format trait std::fmt::Debug and
std::fmt::Display which both format the value as “_”.
assert_that!(format!("{:?}", Unknown)).is_equal_to("_");
assert_that!(format!("{}", Unknown)).is_equal_to("_");Examples
This type is used to implement the expectations
For example for implementing the function Expectation::message() for the
IsOk expectation for Result<T, E> the
concrete types for T and E are not relevant. The implementation of the
trait looks like this:
impl<T, E> Expectation<Result<T, E>> for IsOk
where
T: Debug,
E: Debug,
{
fn test(&mut self, subject: &Result<T, E>) -> bool {
subject.is_ok()
}
fn message(&self, expression: &Expression<'_>, actual: &Result<T, E>, _inverted: bool, _format: &DiffFormat) -> String {
format!(
"expected {expression} is {:?}\n but was: {actual:?}\n expected: {:?}",
Ok::<_, Unknown>(Unknown),
Ok::<_, Unknown>(Unknown),
)
}
}Trait Implementations
impl Copy for Unknown
impl Eq for Unknown
impl StructuralPartialEq for Unknown