Invertible

Trait Invertible 

pub trait Invertible { }
Marks an expectation that it can be inverted by using the Not combinator.

An expectation is any type that implements the Expectation trait.

This trait is meant to be implemented in combination with the Expectation trait. It should only be implemented for an expectation if the inverted test is unmistakably meaningful, and if the failure message clearly states whether the expectation has been inverted or not.

Implementors

Source

impl Invertible for ErrorHasSource

Source

impl Invertible for ErrorHasSourceMessage

Source

impl Invertible for HasAtLeastLength<usize>

Source

impl Invertible for HasAtMostLength<usize>

Source

impl Invertible for HasLength<usize>

Source

impl Invertible for HasLengthGreaterThan<usize>

Source

impl Invertible for HasLengthLessThan<usize>

Source

impl Invertible for HasScaleOf

Source

impl Invertible for IsANumber

Source

impl Invertible for IsAlphabetic

Source

impl Invertible for IsAlphanumeric

Source

impl Invertible for IsAscii

Source

impl Invertible for IsCloseTo<f32, F32Margin>

Available on crate feature float-cmp only.
Source

impl Invertible for IsCloseTo<f64, F64Margin>

Available on crate feature float-cmp only.
Source

impl Invertible for IsControlChar

Source

impl Invertible for IsDigit

Source

impl Invertible for IsEmpty

Source

impl Invertible for IsFalse

Source

impl Invertible for IsFinite

Source

impl Invertible for IsInfinite

Source

impl Invertible for IsLowerCase

Source

impl Invertible for IsNegative

Source

impl Invertible for IsOne

Source

impl Invertible for IsPositive

Source

impl Invertible for IsTrue

Source

impl Invertible for IsUpperCase

Source

impl Invertible for IsWhitespace

Source

impl Invertible for IsZero

Source

impl Invertible for StringContains<&str>

Source

impl Invertible for StringContains<char>

Source

impl Invertible for StringContains<String>

Source

impl Invertible for StringContainsAnyOf<&[char]>

Source

impl Invertible for StringEndsWith<&str>

Source

impl Invertible for StringEndsWith<char>

Source

impl Invertible for StringEndsWith<String>

Source

impl Invertible for StringMatches<'_>

Available on crate feature regex only.
Source

impl Invertible for StringStartWith<&str>

Source

impl Invertible for StringStartWith<char>

Source

impl Invertible for StringStartWith<String>

Source

impl<E> Invertible for HasDebugMessage<E>

Source

impl<E> Invertible for HasDisplayMessage<E>

Source

impl<E> Invertible for HasValue<E>

Source

impl<E> Invertible for IsAfter<E>

Source

impl<E> Invertible for IsAtLeast<E>

Source

impl<E> Invertible for IsAtMost<E>

Source

impl<E> Invertible for IsBefore<E>

Source

impl<E> Invertible for IsBetween<E>

Source

impl<E> Invertible for IsEqualTo<E>

Source

impl<E> Invertible for IsGreaterThan<E>

Source

impl<E> Invertible for IsLessThan<E>

Source

impl<E> Invertible for IsSameAs<E>

Source

impl<E> Invertible for IteratorContains<E>

Source

impl<E> Invertible for IteratorContainsAnyOf<E>

Source

impl<E> Invertible for MapContainsKey<E>

Source

impl<E> Invertible for MapContainsValue<E>

Source

impl<P> Invertible for Predicate<P>

Source

impl<R> Invertible for HasLengthInRange<R, usize>

Source

impl<R, E> Invertible for IsInRange<R, E>

Source

impl<X> Invertible for HasError<X>

Source

impl<const N: usize> Invertible for StringContainsAnyOf<&[char; N]>

Source

impl<const N: usize> Invertible for StringContainsAnyOf<[char; N]>