Definitions of the expectations that are provided by this crate.
Structs
- All
- A combinator expectation that verifies that all containing expectations are met.
- AllSatisfy
- Any
- A combinator expectation that verifies that any containing expectation is met.
- AnySatisfies
- Does
NotPanic panic - Does
Panic panic - Error
HasSource - Error
HasSource Message - HasAt
Least Char Count - HasAt
Least Length - HasAt
Least Number OfElements - HasAt
Most Char Count - HasAt
Most Length - HasChar
Count - HasChar
Count Greater Than - HasChar
Count InRange - HasChar
Count Less Than - HasDebug
Message - HasDisplay
Message - HasError
- HasLength
- HasLength
Greater Than - HasLength
InRange - HasLength
Less Than - HasPrecision
Of - HasScale
Of - HasSingle
Element - HasValue
- IsANumber
- IsAfter
- IsAlphabetic
- IsAlphanumeric
- IsAscii
- IsAt
Least - IsAt
Most - IsBefore
- IsBetween
- IsClose
To - IsControl
Char - IsDigit
- IsEmpty
- IsEqual
To - IsErr
- IsFalse
- IsFinite
- IsGreater
Than - IsIn
Range - IsInfinite
- IsInteger
- IsLess
Than - IsLower
Case - IsNegative
- IsNone
- IsOk
- IsOne
- IsPositive
- IsSame
As - IsSome
- IsTrue
- IsUpper
Case - IsWhitespace
- IsZero
- Iterator
Contains - Iterator
Contains AllIn Order - Iterator
Contains AllOf - Iterator
Contains AnyOf - Iterator
Contains Exactly - Iterator
Contains Exactly InAny Order - Iterator
Contains Only - Iterator
Contains Only Once - Iterator
Contains Sequence - Iterator
Ends With - Iterator
Starts With - MapContains
Exactly Keys - MapContains
Key - MapContains
Keys - MapContains
Value - MapContains
Values - MapDoes
NotContain Keys - MapDoes
NotContain Values - None
Satisfies - Not
- A combinator expectation that inverts the wrapped expectation.
- Predicate
- Rec
- A combinator expectation that memorizes (“records”) the result of the wrapped expectation.
- String
Contains - String
Contains AnyOf - String
Ends With - String
Matches regex - String
Start With
Traits
- IntoRec
- Trait to convert a type into another type that wraps the contained
expectation(s) into
Rec(s).
Functions
- all
- Creates an
Allexpectation combinator from a tuple of expectations. - all_
satisfy - any
- Creates an
Anyexpectation combinator from a tuple of expectations. - any_
satisfies - does_
not_ panic panic - Creates a
DoesNotPanicexpectation. - does_
panic panic - Creates a
DoesPanicexpectation. - error_
has_ source - Creates an
ErrorHasSourceexpectation. - error_
has_ source_ message - Creates an
ErrorHasSourceMessageexpectation. - has_
at_ least_ char_ count - Creates a
HasAtLeastCharCountexpectation. - has_
at_ least_ length - Creates a
HasAtLeastLengthexpectation. - has_
at_ least_ number_ of_ elements - has_
at_ most_ char_ count - Creates a
HasAtMostCharCountexpectation. - has_
at_ most_ length - Creates a
HasAtMostLengthexpectation. - has_
char_ count - Creates a
HasCharCountexpectation. - has_
char_ count_ greater_ than - Creates a
HasCharCountexpectation. - has_
char_ count_ in_ range - Creates a
HasCharCountInRangeexpectation. - has_
char_ count_ less_ than - Creates a
HasCharCountLessThanexpectation. - has_
debug_ message - Creates a
HasDebugMessageexpectation. - has_
display_ message - Creates a
HasDisplayMessageexpectation. - has_
error - Creates a
HasErrorexpectation. - has_
length - Creates a
HasLengthexpectation. - has_
length_ greater_ than - Creates a
HasLengthGreaterThanexpectation. - has_
length_ in_ range - Creates a
HasLengthInRangeexpectation. - has_
length_ less_ than - Creates a
HasLengthLessThanexpectation. - has_
precision_ of - Creates a
HasPrecisionOfexpectation. - has_
scale_ of - Creates a
HasScaleOfexpectation. - has_
single_ element - has_
value - Creates a
HasValueexpectation. - is_
a_ number - Creates an
IsANumberexpectation. - is_
after - Creates an
IsAfterexpectation. - is_
alphabetic - Creates an
IsAlphabeticexpectation. - is_
alphanumeric - Creates an
IsAlphanumericexpectation. - is_
ascii - Creates an
IsAsciiexpectation. - is_
at_ least - Creates an
IsAtLeastexpectation. - is_
at_ most - Creates an
IsAtMostexpectation. - is_
before - Creates an
IsBeforeexpectation. - is_
between - Creates an
IsBetweenexpectation. - is_
close_ to - Creates an
IsCloseToexpectation. - is_
control_ char - Creates an
IsControlCharexpectation. - is_
digit - Creates an
IsDigitexpectation. - is_
empty - Creates an
IsEmptyexpectation. - is_
equal_ to - Creates an
IsEqualToexpectation. - is_err
- Creates an
IsErrexpectation. - is_
false - Creates a
IsFalseexpectation. - is_
finite - Creates an
IsFiniteexpectation. - is_
greater_ than - Creates an
IsGreaterThanexpectation. - is_
in_ range - Creates an
IsInRangeexpectation. - is_
infinite - Creates an
IsInfiniteexpectation. - is_
integer - Creates an
IsIntegerexpectation. - is_
less_ than - Creates an
IsLessThanexpectation. - is_
lower_ case - Creates an
IsLowerCaseexpectation. - is_
negative - Creates an
IsNegativeexpectation. - is_none
- Creates an
IsNoneexpectation. - is_ok
- Creates an
IsOkexpectation. - is_one
- Creates an
IsOneexpectation. - is_
positive - Creates an
IsPositiveexpectation. - is_
same_ as - Creates an
IsSameAsexpectation. - is_some
- Creates an
IsSomeexpectation. - is_true
- Creates an
IsTrueexpectation. - is_
upper_ case - Creates an
IsUpperCaseexpectation. - is_
whitespace - Creates an
IsWhitespaceexpectation. - is_zero
- Creates an
IsZeroexpectation. - iterator_
contains - Creates an
IteratorContainsexpectation. - iterator_
contains_ all_ in_ order - Creates an
IteratorContainsAllInOrderexpectation. - iterator_
contains_ all_ of - Creates an
IteratorContainsAllOfexpectation. - iterator_
contains_ any_ of - Creates an
IteratorContainsAnyOfexpectation. - iterator_
contains_ exactly - Creates an
IteratorContainsExactlyexpectation. - iterator_
contains_ exactly_ in_ any_ order - Creates an
IteratorContainsExactlyInAnyOrderexpectation. - iterator_
contains_ only - Creates an
IteratorContainsOnlyexpectation. - iterator_
contains_ only_ once - Creates an
IteratorContainsOnlyOnceexpectation. - iterator_
contains_ sequence - Creates an
IteratorContainsAnyOfexpectation. - iterator_
ends_ with - Creates an
IteratorEndsWithexpectation. - iterator_
starts_ with - Creates an
IteratorStartsWithexpectation. - map_
contains_ exactly_ keys - Creates a
MapContainsExactlyKeysexpectation. - map_
contains_ key - Creates a
MapContainsKeyexpectation. - map_
contains_ keys - Creates a
MapContainsKeysexpectation. - map_
contains_ value - Creates a
MapContainsValueexpectation. - map_
contains_ values - Creates a
MapContainsValuesexpectation. - map_
does_ not_ contain_ keys - Creates a
MapDoesNotContainKeysexpectation. - map_
does_ not_ contain_ values - Creates a
MapDoesNotContainValuesexpectation. - none_
satisfies - not
- Creates a
Notexpectation combinator wrapping the given expectation. - rec
- Creates a
Recexpectation combinator that wraps the given expectation. - satisfies
- Creates a
Predicateexpectation from a predicate function. - string_
contains - Creates a
StringContainsexpectation. - string_
contains_ any_ of - Creates a
StringContainsAnyOfexpectation. - string_
ends_ with - Creates a
StringEndsWithexpectation. - string_
matches regex - Creates a
StringMatchesexpectation. - string_
starts_ with - Creates a
StringStartWithexpectation.