pub struct All<E>(pub E);Expand description
A combinator expectation that verifies that all containing expectations are met.
Use the function all() to construct an All combinator for a tuple of
expectations.
Tuple Fields
0: ETrait Implementations
Sourceimpl<S, A1: Expectation<S>> Expectation<S> for All<(Rec<A1>,)>
impl<S, A1: Expectation<S>> Expectation<S> for All<(Rec<A1>,)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>, A11: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>, A11: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>)>
Sourceimpl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>, A11: Expectation<S>, A12: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>, Rec<A12>)>
impl<S, A1: Expectation<S>, A2: Expectation<S>, A3: Expectation<S>, A4: Expectation<S>, A5: Expectation<S>, A6: Expectation<S>, A7: Expectation<S>, A8: Expectation<S>, A9: Expectation<S>, A10: Expectation<S>, A11: Expectation<S>, A12: Expectation<S>> Expectation<S> for All<(Rec<A1>, Rec<A2>, Rec<A3>, Rec<A4>, Rec<A5>, Rec<A6>, Rec<A7>, Rec<A8>, Rec<A9>, Rec<A10>, Rec<A11>, Rec<A12>)>