pub trait IntoRec {
type Output;
// Required method
fn into_rec(self) -> Self::Output;
}Expand description
Trait to convert a type into another type that wraps the contained
expectation(s) into Rec(s).
If this type contains multiple expectations like Vec<E: Expectation> or
tuples of expectations, each expectation should be wrapped into its own
Rec.