pub trait Invertible { }Expand description
Marks an expectation that it can be inverted by using the Not
combinator.
An expectation is any type that implements the Expectation trait.
This trait is meant to be implemented in combination with the
Expectation trait. It should only be implemented for an expectation if
the inverted test is unmistakably meaningful, and if the failure message
clearly states whether the expectation has been inverted or not.
Implementors
impl Invertible for ErrorHasSource
impl Invertible for ErrorHasSourceMessage
impl Invertible for HasAtLeastLength<usize>
impl Invertible for HasAtMostLength<usize>
impl Invertible for HasLength<usize>
impl Invertible for HasLengthGreaterThan<usize>
impl Invertible for HasLengthLessThan<usize>
impl Invertible for HasScaleOf
impl Invertible for IsANumber
impl Invertible for IsAlphabetic
impl Invertible for IsAlphanumeric
impl Invertible for IsAscii
impl Invertible for IsCloseTo<f32, F32Margin>
Available on crate feature
float-cmp only.impl Invertible for IsCloseTo<f64, F64Margin>
Available on crate feature
float-cmp only.impl Invertible for IsControlChar
impl Invertible for IsDigit
impl Invertible for IsEmpty
impl Invertible for IsFalse
impl Invertible for IsFinite
impl Invertible for IsInfinite
impl Invertible for IsLowerCase
impl Invertible for IsNegative
impl Invertible for IsOne
impl Invertible for IsPositive
impl Invertible for IsTrue
impl Invertible for IsUpperCase
impl Invertible for IsWhitespace
impl Invertible for IsZero
impl Invertible for StringContains<&str>
impl Invertible for StringContains<char>
impl Invertible for StringContains<String>
impl Invertible for StringContainsAnyOf<&[char]>
impl Invertible for StringEndsWith<&str>
impl Invertible for StringEndsWith<char>
impl Invertible for StringEndsWith<String>
impl Invertible for StringMatches<'_>
Available on crate feature
regex only.